#!/usr/bin/env python
# -*- coding: utf-8 -*-

# py_tools_ds
#
# Copyright (C) 2019  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
#
# This software was developed within the context of the GeoMultiSens project funded
# by the German Federal Ministry of Education and Research
# (project grant code: 01 IS 14 010 A-C).
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
test_conversion
---------------

Tests for `py_tools_ds.geo.raster.conversion` module.
"""

import os
from unittest import TestCase

from osgeo import gdal

from py_tools_ds.geo.raster.conversion import raster2polygon
import py_tools_ds

tests_path = os.path.abspath(os.path.join(py_tools_ds.__file__, "..", "..", "tests"))


class Test_raster2polygon(TestCase):
    def setUp(self) -> None:
        try:
            # load a large mask containing an irregular binary shape with a complex footprint (27408x17604)
            ds = gdal.Open(os.path.join(tests_path, 'data', 'mask_large.tif'))
            self.mask = ds.ReadAsArray().astype(bool)
            self.gt = ds.GetGeoTransform()
            self.prj = ds.GetProjection()

        finally:
            del ds

    def test_raster2polygon(self):
        raster2polygon(self.mask, self.gt, self.prj, exact=False)
